@@ -15,7 +15,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(lint_prereqs);
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 $SPEC{lint_prereqs} = {
     v => 1.1,
@@ -24,11 +24,11 @@ $SPEC{lint_prereqs} = {
 
 Check [Prereqs / *] sections in your dist.ini against what's actually being used
 in your Perl code (using Perl::PrereqScanner) and what's in Perl core list of
-modules. Will complain if your prereqs is not actually used, or already in Perl
-core. Will also complain if there are missing prereqs.
+modules. Will complain if your prerequisites are not actually used, or already
+in Perl core. Will also complain if there are missing prerequisites.
 
-Designed to work with prereqs that are manually written. Does not work if you
-use AutoPrereqs.
+Designed to work with prerequisites that are manually written. Does not work if
+you use AutoPrereqs.
 
 Sometimes there are prerequisites that you know are used but can't be detected
 by scan_prereqs, or you want to include anyway. If this is the case, you can
@@ -134,21 +134,19 @@ sub lint_prereqs {
         $core_mods{$1} = $2 // 0;
     }
 
-    my $err;
-
+    my @errs;
     for my $mod (keys %mods_from_ini) {
         next if $mod eq 'perl';
         $log->tracef("Checking mod from dist.ini: %s", $mod);
         if (exists($core_mods{$mod}) &&
                 versioncmp($core_mods{$mod}, $mods_from_ini{$mod}) >= 0) {
-            $log->warnf("Module is core, but mentioned in dist.ini: %s", $mod);
-            $err++;
+            push @errs, {
+                module=>$mod, message=>"Core but mentioned"};
         }
         unless (exists($mods_from_scanned{$mod}) ||
                     exists($assume_used{$mod})) {
-            $log->warnf("Module doesn't seem to be used, ".
-                            "but mentioned in dist.ini: %s", $mod);
-            $err++;
+            push @errs, {
+                module=>$mod, message=>"Unused but mentioned"};
         }
     }
 
@@ -159,16 +157,13 @@ sub lint_prereqs {
         next if exists $pkgs{$mod};
         unless (exists($mods_from_ini{$mod}) ||
                     exists($assume_provided{$mod})) {
-            $log->errorf("Module is used, but not mentioned in dist.ini: %s",
-                         $mod);
-            $err++;
+            push @errs, {
+                module=>$mod, message=>"Used but not mentioned"};
         }
     }
 
-    $err ?
-        [500, "Extraneous/missing dependencies", undef,
-         {"cmdline.display_result"=>0}] :
-            [200, "OK"];
+    [200, @errs ? "Extraneous/missing dependencies" : "OK", \@errs,
+     {"cmdline.exit_code" => @errs ? 1:0}];
 }
 
 1;
@@ -184,36 +179,29 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
  # Use via lint-prereqs CLI script
 
-=head1 DESCRIPTION
-
-
-This module has L<Rinci> metadata.
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 lint_prereqs(%args) -> [status, msg, result, meta]
 
 Check extraneous/missing prerequisites in dist.ini.
 
 Check [Prereqs / *] sections in your dist.ini against what's actually being used
 in your Perl code (using Perl::PrereqScanner) and what's in Perl core list of
-modules. Will complain if your prereqs is not actually used, or already in Perl
-core. Will also complain if there are missing prereqs.
+modules. Will complain if your prerequisites are not actually used, or already
+in Perl core. Will also complain if there are missing prerequisites.
 
-Designed to work with prereqs that are manually written. Does not work if you
-use AutoPrereqs.
+Designed to work with prerequisites that are manually written. Does not work if
+you use AutoPrereqs.
 
 Sometimes there are prerequisites that you know are used but can't be detected
-by scanI<prereqs, or you want to include anyway. If this is the case, you can
+by scanB<prereqs, or you want to include anyway. If this is the case, you can
 instruct lint>prereqs to assume the prerequisite is used.
 
     ;!lint-prereqs assume-used # even though we know it is not currently used
